@@ -182,148 +182,6 @@ brasero_utils_unregister_string (const gchar *string)
 	G_UNLOCK (stringsH);
 }
 
-gchar *
-brasero_utils_get_time_string (guint64 time,
-			       gboolean with_unit,
-			       gboolean round)
-{
-	gint64 second, minute, hour;
-
-	time /= 1000000000;
-	hour = time / 3600;
-	time = time % 3600;
-	minute = time / 60;
-
-	if (round) {
-		if ((time % 60) > 30)
-			minute ++;
-
-		second = 0;
-	}
-	else
-		second = time % 60;
-
-	if (hour) {
-		if (with_unit) {
-			if (hour && minute && second)
-				return g_strdup_printf ("%lli h %02lli min %02lli",
-							 hour,
-							 minute,
-							 second);
-			else if (hour && minute)
-				return g_strdup_printf ("%lli h %02lli",
-							 hour,
-							 minute);
-			else
-				return g_strdup_printf ("%lli h",hour);
-		}
-		else if (hour && minute && second)
-			return g_strdup_printf ("%lli:%02lli:%02lli",
-						 hour,
-						 minute,
-						 second);
-		else if (hour && minute)
-			return g_strdup_printf ("%lli:%02lli", hour, minute);
-	}
-
-	if (with_unit) {
-		if (!second)
-			return g_strdup_printf (_("%lli min"), minute);
-		else
-			return g_strdup_printf (_("%lli:%02lli min"), minute, second);
-	}
-	else
-		return g_strdup_printf ("%lli:%02lli", minute, second);
-}
-
-gchar *
-brasero_utils_get_time_string_from_size (gint64 size,
-					 gboolean with_unit,
-					 gboolean round)
-{
-	guint64 time = 0;
-
-	time = BRASERO_BYTES_TO_DURATION (size);
-	return brasero_utils_get_time_string (time, with_unit, round);
-}
-
-enum {
-	BRASERO_UTILS_NO_UNIT,
-	BRASERO_UTILS_KO,
-	BRASERO_UTILS_MO,
-	BRASERO_UTILS_GO
-};
-
-gchar *
-brasero_utils_get_size_string (gint64 dsize,
-			       gboolean with_unit,
-			       gboolean round)
-{
-	int unit;
-	int size;
-	int remain = 0;
-
-	if (with_unit)
-		return g_format_size_for_display (dsize);
-
-	if (dsize < 1024) {
-		unit = BRASERO_UTILS_NO_UNIT;
-		size = (int) dsize;
-		goto end;
-	}
-
-	size = (int) (dsize / 1024);
-	if (size < 1024) {
-		unit = BRASERO_UTILS_KO;
-		goto end;
-	}
-
-	size = (int) (size / 1024);
-	if (size < 1024) {
-		unit = BRASERO_UTILS_MO;
-		goto end;
-	}
-
-	remain = (size % 1024) / 100;
-	size = size / 1024;
-	unit = BRASERO_UTILS_GO;
-
-      end:
-
-	if (round && size > 10) {
-		gint remains;
-
-		remains = size % 10;
-		size -= remains;
-	}
-
-	if (remain)
-		return g_strdup_printf ("%i.%i",
-					size,
-					remain);
-	else
-		return g_strdup_printf ("%i",
-					size);
-}
-
-gchar *
-brasero_utils_get_sectors_string (gint64 sectors,
-				  gboolean time_format,
-				  gboolean with_unit,
-				  gboolean round)
-{
-	gint64 size;
-
-	if (time_format) {
-		size = sectors * GST_SECOND / 75;
-		return brasero_utils_get_time_string (size, with_unit, round);
-	}
-	else {
-		size = sectors * 2048;
-		return brasero_utils_get_size_string (size, with_unit, round);
-	}
-}
-
 GtkWidget *
 brasero_utils_pack_properties_list (const gchar *title, GSList *list)
 {
@@ -426,35 +284,6 @@ brasero_utils_make_button (const gchar *text,
 	return button;
 }
 
-/* Copied from glib-2.8.3 (glib.c) but slightly
- * modified to use only the first 64 bytes */
-gboolean
-brasero_utils_str_equal_64 (gconstpointer v1,
-			    gconstpointer v2)
-{
-  const gchar *string1 = v1;
-  const gchar *string2 = v2;
-  
-  return strncmp (string1, string2, 64) == 0;
-}
-
-/* Copied from glib-2.8.3 (glib.c) but slightly
- * modified to use only the first 64 bytes */
-guint
-brasero_utils_str_hash_64 (gconstpointer v)
-{
-  /* 31 bit hash function */
-  const signed char *p = v;
-  guint32 h = *p;
-  int i;
-
-  if (h)
-    for (p += 1, i = 0; *p != '\0' && i < 64; p++, i++)
-      h = (h << 5) - h + *p;
-
-  return h;
-}
-
 void
 brasero_utils_launch_app (GtkWidget *widget,
 			  GSList *list)
@@ -472,7 +301,7 @@ brasero_utils_launch_app (GtkWidget *widget,
 			gchar *string;
 
 			string = g_strdup_printf ("\"%s\" could not be opened", uri);
-			brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (widget))),
+			brasero_app_alert (brasero_app_get_default (),
 					   string,
 					   error->message,
 					   GTK_MESSAGE_ERROR);
@@ -522,6 +351,7 @@ brasero_utils_create_message_dialog (GtkWidget *parent,
 					  GTK_DIALOG_DESTROY_WITH_PARENT,
 					  type,
 					  GTK_BUTTONS_CLOSE,
+					  "%s",
 					  primary_message);
 
 	gtk_window_set_title (GTK_WINDOW (message), "");
@@ -550,3 +380,32 @@ brasero_utils_message_dialog (GtkWidget *parent,
 	gtk_dialog_run (GTK_DIALOG (message));
 	gtk_widget_destroy (message);
 }
+
+gboolean
+brasero_clipboard_selection_may_have_uri (GdkAtom *atoms,
+					  gint n_atoms)
+{
+	GdkAtom *iter;
+
+	/* Check for a text target */
+	if (gtk_targets_include_text (atoms, n_atoms))
+		return TRUE;
+
+	/* Check for special targets like nautilus' and its file copied */
+	iter = atoms;
+	while (n_atoms > 0) {
+		gchar *target;
+
+		target = gdk_atom_name (*iter);
+		if (!strcmp (target, "x-special/gnome-copied-files")) {
+			g_free (target);
+			return TRUE;
+		}
+		g_free (target);
+
+		iter++;
+		n_atoms--;
+	}
+
+	return FALSE;
+}
