@@ -56,23 +56,6 @@ void brasero_utils_init (void);
 
 GQuark brasero_error_quark (void);
 
-gchar *brasero_utils_get_time_string (guint64 time,
-				      gboolean with_unit,
-				      gboolean round);
-
-gchar *brasero_utils_get_time_string_from_size (gint64 time,
-						gboolean with_unit,
-						gboolean round);
-
-gchar *brasero_utils_get_size_string (gint64 size,
-				      gboolean with_unit,
-				      gboolean round);
-gchar *
-brasero_utils_get_sectors_string (gint64 sectors,
-				  gboolean time_format,
-				  gboolean with_unit,
-				  gboolean round);
-
 gchar *
 brasero_utils_register_string (const gchar *string);
 void
@@ -88,13 +71,6 @@ brasero_utils_make_button (const gchar *text,
 			   const gchar *theme,
 			   GtkIconSize size);
 
-gboolean
-brasero_utils_str_equal_64 (gconstpointer v1,
-			    gconstpointer v2);
-
-guint
-brasero_utils_str_hash_64 (gconstpointer v);
-
 void
 brasero_utils_launch_app (GtkWidget *widget,
 			  GSList *list);
@@ -114,6 +90,10 @@ brasero_utils_message_dialog (GtkWidget *parent,
 			      const gchar *secondary_message,
 			      GtkMessageType type);
 
+gboolean
+brasero_clipboard_selection_may_have_uri (GdkAtom *atoms,
+					  gint n_atoms);
+
 G_END_DECLS
 
 #endif				/* _UTILS_H */
