@@ -739,7 +739,10 @@ brasero_video_disc_clipboard_text_cb (GtkClipboard *clipboard,
 	gchar **array;
 	gchar **item;
 
-	array = g_strsplit_set (text, "\n\r", 0);
+	if (!text)
+		return;
+
+	array = g_uri_list_extract_uris (text);
 	item = array;
 	while (*item) {
 		if (**item != '\0') {
@@ -761,6 +764,7 @@ brasero_video_disc_clipboard_text_cb (GtkClipboard *clipboard,
 
 		item++;
 	}
+	g_strfreev (array);
 }
 
 static void
@@ -769,26 +773,10 @@ brasero_video_disc_clipboard_targets_cb (GtkClipboard *clipboard,
 					 gint n_atoms,
 					 BraseroVideoDisc *self)
 {
-	GdkAtom *iter;
-	gchar *target;
-
-	iter = atoms;
-	while (n_atoms) {
-		target = gdk_atom_name (*iter);
-
-		if (!strcmp (target, "x-special/gnome-copied-files")
-		||  !strcmp (target, "UTF8_STRING")) {
-			gtk_clipboard_request_text (clipboard,
-						    (GtkClipboardTextReceivedFunc) brasero_video_disc_clipboard_text_cb,
-						    self);
-			g_free (target);
-			return;
-		}
-
-		g_free (target);
-		iter++;
-		n_atoms--;
-	}
+	if (brasero_clipboard_selection_may_have_uri (atoms, n_atoms))
+		gtk_clipboard_request_text (clipboard,
+					    (GtkClipboardTextReceivedFunc) brasero_video_disc_clipboard_text_cb,
+					    self);
 }
 
 static void
