@@ -1901,8 +1901,8 @@ brasero_job_set_rate (BraseroJob *self,
 
 BraseroBurnResult
 brasero_job_set_output_size_for_current_track (BraseroJob *self,
-					       gint64 sectors,
-					       gint64 size)
+					       goffset sectors,
+					       goffset bytes)
 {
 	BraseroJobPrivate *priv;
 
@@ -1922,12 +1922,12 @@ brasero_job_set_output_size_for_current_track (BraseroJob *self,
 
 	return brasero_task_ctx_set_output_size_for_current_track (priv->ctx,
 								   sectors,
-								   size);
+								   bytes);
 }
 
 BraseroBurnResult
 brasero_job_set_written_track (BraseroJob *self,
-			       gint64 written)
+			       goffset written)
 {
 	BraseroJobPrivate *priv;
 
@@ -1943,7 +1943,7 @@ brasero_job_set_written_track (BraseroJob *self,
 
 BraseroBurnResult
 brasero_job_set_written_session (BraseroJob *self,
-				 gint64 written)
+				 goffset written)
 {
 	BraseroJobPrivate *priv;
 
